@@ -3,4 +3,6 @@ x<-na.omit(x)
 step1<-as.factor(x)
 m<-summary(step1)
 m1<-which(m==max(m))
-ifelse(nlevels(step1)==1, "No mode", as.numeric(names(m1)))}
+if(all(m==1)) print("No mode")
+else
+as.numeric(names(m1))}
